@@ -71,12 +71,20 @@ DTWidget.formatDate = function(data, method, params) {
 
 window.DTWidget = DTWidget;
 
-// A helper function to update the lims of the existing filters
-var set_filter_lims = function(td, new_vals) {
+// A helper function to update the properties of existing filters
+var setFilterProps = function(td, props) {
+  // Update enabled/disabled state
+  var $input = $(td).find('input').first();
+  var searchable = $input.data('searchable');
+  $input.prop('disabled', !searchable || props.disabled);
+
   // Based on the filter type, set its new values
-  if (['factor', 'logical'].includes(td.getAttribute('data-type'))) {
+  var type = td.getAttribute('data-type');
+  if (['factor', 'logical'].includes(type)) {
     // Reformat the new dropdown options for use with selectize
-    new_vals = new_vals.map(function(item) {return {text: item, value: item}});
+    var new_vals = props.params.options.map(function(item) {
+      return { text: item, value: item };
+    });
 
     // Find the selectize object
     var dropdown = $(td).find('.selectized').eq(0)[0].selectize;
@@ -93,12 +101,16 @@ var set_filter_lims = function(td, new_vals) {
     // Preserve the existing values
     dropdown.setValue(old_vals);
 
-  } else if (['number', 'integer', 'date', 'time'].includes(td.getAttribute('data-type'))) {
+  } else if (['number', 'integer', 'date', 'time'].includes(type)) {
+    // Apply internal scaling to new limits. Updating scale not yet implemented.
+    var slider = $(td).find('.noUi-target').eq(0);
+    var scale = Math.pow(10, Math.max(0, +slider.data('scale') || 0));
+    var new_vals = [props.params.min * scale, props.params.max * scale];
+
     // Note what the new limits will be just for this filter
-    var new_lims = [...new_vals];
+    var new_lims = new_vals.slice();
 
     // Determine the current values and limits
-    var slider = $(td).find('.noUi-target').eq(0);
     var old_vals = slider.val().map(Number);
     var old_lims = slider.noUiSlider('options').range;
     old_lims = [old_lims.min, old_lims.max];
@@ -151,6 +163,12 @@ HTMLWidgets.widget({
   type: "output",
   renderOnNullValue: true,
   initialize: function(el, width, height) {
+    // in order that the type=number inputs return a number
+    $.valHooks.number = {
+      get: function(el) {
+        return el.value * 1;
+      }
+    };
     $(el).html('&nbsp;');
     return {
       data: null,
@@ -406,13 +424,6 @@ HTMLWidgets.widget({
       return $.inArray(val, $.makeArray(array)) > -1;
     };
 
-    // encode + to %2B when searching in the table on server side, because
-    // shiny::parseQueryString() treats + as spaces, and DataTables does not
-    // encode + to %2B (or % to %25) when sending the request
-    var encode_plus = function(x) {
-      return server ? x.replace(/%/g, '%25').replace(/\+/g, '%2B') : x;
-    };
-
     // search the i-th column
     var searchColumn = function(i, value) {
       var regex = false, ci = true;
@@ -420,7 +431,7 @@ HTMLWidgets.widget({
         regex = options.search.regex,
         ci = options.search.caseInsensitive !== false;
       }
-      return table.column(i).search(encode_plus(value), regex, !regex, ci);
+      return table.column(i).search(value, regex, !regex, ci);
     };
 
     if (data.filter !== 'none') {
@@ -429,7 +440,10 @@ HTMLWidgets.widget({
 
         var $td = $(td), type = $td.data('type'), filter;
         var $input = $td.children('div').first().children('input');
-        $input.prop('disabled', !table.settings()[0].aoColumns[i].bSearchable || type === 'disabled');
+        var disabled = $input.prop('disabled');
+        var searchable = table.settings()[0].aoColumns[i].bSearchable;
+        $input.prop('disabled', !searchable || disabled);
+        $input.data('searchable', searchable); // for updating later
         $input.on('input blur', function() {
           $input.next('span').toggle(Boolean($input.val()));
         });
@@ -494,7 +508,7 @@ HTMLWidgets.widget({
               if (value.length) $input.trigger('input');
               $input.attr('title', $input.val());
               if (server) {
-                table.column(i).search(value.length ? encode_plus(JSON.stringify(value)) : '').draw();
+                table.column(i).search(value.length ? JSON.stringify(value) : '').draw();
                 return;
               }
               // turn off filter if nothing selected
@@ -1416,16 +1430,19 @@ HTMLWidgets.widget({
     }
 
     // update table filters (set new limits of sliders)
-    methods.updateFilters = function(newLims) {
+    methods.updateFilters = function(newProps) {
       // loop through each filter in the filter row
       filterRow.each(function(i, td) {
         var k = i;
-        if (filterRow.length > newLims.length) {
+        if (filterRow.length > newProps.length) {
           if (i === 0) return;  // first column is row names
           k = i - 1;
         }
-        // Update the filters to reflect the updated data
-        set_filter_lims(td, newLims[k]);
+        // Update the filters to reflect the updated data.
+        // Allow "falsy" (e.g. NULL) to signify a no-op.
+        if (newProps[k]) {
+          setFilterProps(td, newProps[k]);
+        }
       });
     };
 
